#!/bin/sh -x

function ApplyNWFPE
{
	sed -e 's/# CONFIG_FPE_NWFPE is not set/CONFIG_FPE_NWFPE=y/g' \
	-e 's/CONFIG_FPE_FASTFPE=y/# CONFIG_FPE_FASTFPE is not set/g' .config > .newconfig
	mv .newconfig .config
}

function ApplyFastFPE
{
	sed -e 's/# CONFIG_FPE_FASTFPE is not set/CONFIG_FPE_FASTFPE=y/g' \
	-e 's/CONFIG_FPE_NWFPE=y/# CONFIG_FPE_NWFPE is not set/g' .config > .newconfig
	mv .newconfig .config
}

function ApplyCachedFB
{
	sed -e 's/# CONFIG_SHARPSL_PXA_CONSISTENT_ALLOC is not set/CONFIG_SHARPSL_PXA_CONSISTENT_ALLOC=y/g' .config > .newconfig
	mv .newconfig .config
}

function ApplyUncachedFB
{
	sed -e 's/CONFIG_SHARPSL_PXA_CONSISTENT_ALLOC=y/# CONFIG_SHARPSL_PXA_CONSISTENT_ALLOC is not set/g' .config > .newconfig
	mv .newconfig .config
}

function MakeZImage
{
	echo | make oldconfig
	make dep
	make clean
	make -j3 zImage
	mkdir -p "../images/$1"
	cp arch/arm/boot/zImage "../images/$1/"
	cp .config "../images/$1/kernel_config"
	OLDPWD="$PWD"
	cd "../images/$1/"
	md5sum "zImage" > "zImage.md5"
	cd "$OLDPWD"
}

function MakeModules
{
	make -j3 modules
	rm -Rf /tmp/modules
	mkdir -p /tmp/modules
	make modules_install INSTALL_MOD_PATH=/tmp/modules
	mkdir -p "../images/$1"
	OLDPWD="$PWD"
	cd /tmp/modules
	tar czf "$OLDPWD/../images/$1/modules.tar.gz" lib
	rm -Rf /tmp/modules
	cd "$OLDPWD"
	cd "../images/$1/"
	md5sum "modules.tar.gz" > "modules.tar.gz.md5"
	cd "$OLDPWD"
}

function BuildConfig
{
	cd linux
	make mrproper

	cp "../configs/$1" .config
	ApplyCachedFB
	ApplyFastFPE
	MakeZImage "$1/kernel-fastfpe-cachedfb"

	ApplyNWFPE
	MakeZImage "$1/kernel-nwfpe-cachedfb"

	ApplyUncachedFB
	MakeZImage "$1/kernel-nwfpe-uncachedfb"

	ApplyFastFPE
	MakeZImage "$1/kernel-fastfpe-uncachedfb"
	
	MakeModules "$1"
}

BuildConfig SL-C3200-terrier
BuildConfig SL-C3100-borzoi
BuildConfig SL-C3000-spitz
BuildConfig SL-C1000-akita
